@@ -9,6 +9,7 @@ except ImportError:                  # pragma: no cover
 import socket
 from . import config
 from . import registry
+from .dev.helpers import in_virtual
 
 # NOTE: THIS CODE RUNS ON IMPORT!
 
@@ -19,16 +20,14 @@ from . import registry
 SOCKETS_TIMEOUT = float(config.SOCKETS_TIMEOUT)
 THREADS_TIMEOUT = float(config.THREADS_TIMEOUT)
 
-
-def is_virtual():
-    import sys
-    return True if hasattr(sys, 'real_prefix') else False
-
+# setup paths for contrib
+pkg_path = os.path.dirname(registry.__file__)
+plugins_path = os.path.join(pkg_path, 'contrib/plugins')
 
 try:
     # read conf file
     conf = configparser.ConfigParser()
-    if is_virtual():
+    if in_virtual():
         conf.read([os.path.join(sys.prefix, 'isbntools.conf')])
     else:
         if os.name == 'nt':          # pragma: no cover
@@ -59,10 +58,15 @@ try:
 
     if conf.has_section('PLUGINS'):  # pragma: no cover
         for o, v in conf.items('PLUGINS'):
-            plugin = registry.load_plugin(o, v)
+            path = v if '/' in v or '\\' in v else plugins_path
+            plugin = registry.load_plugin(o, path)
             if plugin:
                 registry.add_service(o, plugin.query)
 
+    if conf.has_section('MODULES'):  # pragma: no cover
+        for o, v in conf.items('MODULES'):
+            config.set_option(o.upper(), v)
+
 except:                              # pragma: no cover
     pass
 
