@@ -17,14 +17,12 @@ def goos(words):
     user_agent = 'w3m/0.5.2'
 
     content = webservice.query(search_url, user_agent)
-
     isbns = get_isbnlike(content)
 
     for item in isbns:
         isbn = get_canonical_isbn(item, output='isbn13')
         if isbn:
             break
-    if not isbn:
+    if not isbn:    # pragma: no cover
         LOGGER.debug('No ISBN found for %s', words)
-        return
-    return isbn
+    return isbn if isbn else None
